export default {
    labelIdle: 'Dra og slipp filene dine, eller <span class="filepond--label-action"> Bla gjennom... </span>',
    labelInvalidField: 'Feltet inneholder ugyldige filer',
    labelFileWaitingForSize: 'Venter på størrelse',
    labelFileSizeNotAvailable: 'Størrelse ikke tilgjengelig',
    labelFileLoading: 'Laster',
    labelFileLoadError: 'Feil under lasting',
    labelFileProcessing: 'Laster opp',
    labelFileProcessingComplete: 'Opplasting ferdig',
    labelFileProcessingAborted: 'Opplasting avbrutt',
    labelFileProcessingError: 'Feil under opplasting',
    labelFileProcessingRevertError: 'Feil under reversering',
    labelFileRemoveError: 'Feil under flytting',
    labelTapToCancel: 'klikk for å avbryte',
    labelTapToRetry: 'klikk for å prøve på nytt',
    labelTapToUndo: 'klikk for å angre',
    labelButtonRemoveItem: 'Fjern',
    labelButtonAbortItemLoad: 'Avbryt',
    labelButtonRetryItemLoad: 'Prøv på nytt',
    labelButtonAbortItemProcessing: 'Avbryt',
    labelButtonUndoItemProcessing: 'Angre',
    labelButtonRetryItemProcessing: 'Prøv på nytt',
    labelButtonProcessItem: 'Last opp',
    labelMaxFileSizeExceeded: 'Filen er for stor',
    labelMaxFileSize: 'Maksimal filstørrelse er {filesize}',
    labelMaxTotalFileSizeExceeded: 'Maksimal total størrelse oversteget',
    labelMaxTotalFileSize: 'Maksimal total størrelse er {filesize}',
    labelFileTypeNotAllowed: 'Ugyldig filtype',
    fileValidateTypeLabelExpectedTypes: 'Forventer {allButLastType} eller {lastType}',
    imageValidateSizeLabelFormatError: 'Bildeformat ikke støttet',
    imageValidateSizeLabelImageSizeTooSmall: 'Bildet er for lite',
    imageValidateSizeLabelImageSizeTooBig: 'Bildet er for stort',
    imageValidateSizeLabelExpectedMinSize: 'Minimumsstørrelse er {minWidth} × {minHeight}',
    imageValidateSizeLabelExpectedMaxSize: 'Maksimumsstørrelse er {maxWidth} × {maxHeight}',
    imageValidateSizeLabelImageResolutionTooLow: 'Oppløsningen er for lav',
    imageValidateSizeLabelImageResolutionTooHigh: 'Oppløsningen er for høy',
    imageValidateSizeLabelExpectedMinResolution: 'Minimum oppløsning er {minResolution}',
    imageValidateSizeLabelExpectedMaxResolution: 'Maksimal oppløsning er {maxResolution}'
};
