export default {
    labelIdle: 'ទាញ&ដាក់ហ្វាល់ឯកសាររបស់អ្នក ឬ <span class="filepond--label-action"> ស្វែងរក </span>',
    labelInvalidField: 'ចន្លោះមានឯកសារមិនត្រឹមត្រូវ',
    labelFileWaitingForSize: 'កំពុងរង់ចាំទំហំ',
    labelFileSizeNotAvailable: 'ទំហំមិនអាចប្រើបាន',
    labelFileLoading: 'កំពុងដំណើរការ',
    labelFileLoadError: 'មានបញ្ហាកំឡុងពេលដំណើរការ',
    labelFileProcessing: 'កំពុងផ្ទុកឡើង',
    labelFileProcessingComplete: 'ការផ្ទុកឡើងពេញលេញ',
    labelFileProcessingAborted: 'ការបង្ហោះត្រូវបានបោះបង់',
    labelFileProcessingError: 'មានបញ្ហាកំឡុងពេលកំពុងផ្ទុកឡើង',
    labelFileProcessingRevertError: 'មានបញ្ហាកំឡុងពេលត្រឡប់',
    labelFileRemoveError: 'មានបញ្ហាកំឡុងពេលដកចេញ',
    labelTapToCancel: 'ចុចដើម្បីបោះបង់',
    labelTapToRetry: 'ចុចដើម្បីព្យាយាមម្តងទៀត',
    labelTapToUndo: 'ចុចដើម្បីមិនធ្វើវិញ',
    labelButtonRemoveItem: 'យកចេញ',
    labelButtonAbortItemLoad: 'បោះបង់',
    labelButtonRetryItemLoad: 'ព្យាយាមម្តងទៀត',
    labelButtonAbortItemProcessing: 'បោះបង់',
    labelButtonUndoItemProcessing: 'មិនធ្វើវិញ',
    labelButtonRetryItemProcessing: 'ព្យាយាមម្តងទៀត',
    labelButtonProcessItem: 'ផ្ទុកឡើង',
    labelMaxFileSizeExceeded: 'ឯកសារធំពេក',
    labelMaxFileSize: 'ទំហំឯកសារអតិបរមាគឺ {filesize}',
    labelMaxTotalFileSizeExceeded: 'លើសទំហំសរុបអតិបរមា',
    labelMaxTotalFileSize: 'ទំហំឯកសារសរុបអតិបរមាគឺ {filesize}',
    labelFileTypeNotAllowed: 'ប្រភេទឯកសារមិនត្រឹមត្រូវ',
    fileValidateTypeLabelExpectedTypes: 'រំពឹងថា {allButLastType} ឬ {lastType}',
    imageValidateSizeLabelFormatError: 'ប្រភេទរូបភាពមិនត្រឹមត្រូវ',
    imageValidateSizeLabelImageSizeTooSmall: 'រូបភាពតូចពេក',
    imageValidateSizeLabelImageSizeTooBig: 'រូបភាពធំពេក',
    imageValidateSizeLabelExpectedMinSize: 'ទំហំអប្បបរមាគឺ {minWidth} × {minHeight}',
    imageValidateSizeLabelExpectedMaxSize: 'ទំហំអតិបរមាគឺ {maxWidth} × {maxHeight}',
    imageValidateSizeLabelImageResolutionTooLow: 'គុណភាពបង្ហាញទាបពេក',
    imageValidateSizeLabelImageResolutionTooHigh: 'គុណភាពបង្ហាញខ្ពស់ពេក',
    imageValidateSizeLabelExpectedMinResolution: 'គុណភាពបង្ហាញអប្បបរមាគឺ {minResolution}',
    imageValidateSizeLabelExpectedMaxResolution: 'គុណភាពបង្ហាញអតិបរមាគឺ {maxResolution}'
};
