export default {
    labelIdle: 'Перетягніть файли або <span class="filepond--label-action"> виберіть </span>',
    labelInvalidField: 'Поле містить недопустимі файли',
    labelFileWaitingForSize: 'Вкажіть розмір',
    labelFileSizeNotAvailable: 'Розмір не доступний',
    labelFileLoading: 'Очікування',
    labelFileLoadError: 'Помилка при очікуванні',
    labelFileProcessing: 'Завантаження',
    labelFileProcessingComplete: 'Завантаження завершено',
    labelFileProcessingAborted: 'Завантаження скасовано',
    labelFileProcessingError: 'Помилка при завантаженні',
    labelFileProcessingRevertError: 'Помилка при відновленні',
    labelFileRemoveError: 'Помилка при видаленні',
    labelTapToCancel: 'Відмінити',
    labelTapToRetry: 'Натисніть, щоб повторити спробу',
    labelTapToUndo: 'Натисніть, щоб відмінити останню дію',
    labelButtonRemoveItem: 'Видалити',
    labelButtonAbortItemLoad: 'Відмінити',
    labelButtonRetryItemLoad: 'Повторити спробу',
    labelButtonAbortItemProcessing: 'Відмінити',
    labelButtonUndoItemProcessing: 'Відмінити останню дію',
    labelButtonRetryItemProcessing: 'Повторити спробу',
    labelButtonProcessItem: 'Завантаження',
    labelMaxFileSizeExceeded: 'Файл занадто великий',
    labelMaxFileSize: 'Максимальний розмір файлу: {filesize}',
    labelMaxTotalFileSizeExceeded: 'Перевищено максимальний загальний розмір',
    labelMaxTotalFileSize: 'Максимальний загальний розмір: {filesize}',
    labelFileTypeNotAllowed: 'Формат файлу не підтримується',
    fileValidateTypeLabelExpectedTypes: 'Очікується {allButLastType} або {lastType}',
    imageValidateSizeLabelFormatError: 'Формат зображення не підтримується',
    imageValidateSizeLabelImageSizeTooSmall: 'Зображення занадто маленьке',
    imageValidateSizeLabelImageSizeTooBig: 'Зображення занадто велике',
    imageValidateSizeLabelExpectedMinSize: 'Мінімальний розмір: {minWidth} × {minHeight}',
    imageValidateSizeLabelExpectedMaxSize: 'Максимальний розмір: {maxWidth} × {maxHeight}',
    imageValidateSizeLabelImageResolutionTooLow: 'Розміри зображення занадто маленькі',
    imageValidateSizeLabelImageResolutionTooHigh: 'Розміри зображення занадто великі',
    imageValidateSizeLabelExpectedMinResolution: 'Мінімальні розміри: {minResolution}',
    imageValidateSizeLabelExpectedMaxResolution: 'Максимальні розміри: {maxResolution}'
};
