export default {
    labelIdle: 'ፋይሎች ስበው እዚህ ጋር ይልቀቁት ወይም ፋይሉን <span class="filepond--label-action"> ይምረጡ </span>',
    labelInvalidField: 'መስኩ ልክ ያልሆኑ ፋይሎችን ይዟል',
    labelFileWaitingForSize: 'የፋይሉን መጠን በመጠባበቅ ላይ',
    labelFileSizeNotAvailable: 'የፋይሉን መጠን ሊገኝ አልቻለም',
    labelFileLoading: 'በማንበብ ላይ',
    labelFileLoadError: 'በማንበብ ላይ ችግር ተፈጥሯል',
    labelFileProcessing: 'ፋይሉን በመጫን ላይ',
    labelFileProcessingComplete: 'ፋይሉን መጫን ተጠናቅቋል',
    labelFileProcessingAborted: 'ፋይሉን መጫን ተቋርጧል',
    labelFileProcessingError: 'ፋይሉን በመጫን ላይ ችግር ተፈጥሯል',
    labelFileProcessingRevertError: 'ፈይሉን በመቀልበስ ላይ ችግር ተፈጥሯል',
    labelFileRemoveError: 'በማጥፋት ላይ ችግር ተፈጥሯል',
    labelTapToCancel: 'ለማቋረጥ ነካ ያድርጉ',
    labelTapToRetry: 'ደግሞ ለመሞከር ነካ ያድርጉ',
    labelTapToUndo: 'ወደነበረበት ለመመለስ ነካ ያድርጉ',
    labelButtonRemoveItem: 'ላጥፋ',
    labelButtonAbortItemLoad: 'ላቋርጥ',
    labelButtonRetryItemLoad: 'ደግሜ ልሞክር',
    labelButtonAbortItemProcessing: 'ይቅር',
    labelButtonUndoItemProcessing: 'ወደነበረበት ልመልስ',
    labelButtonRetryItemProcessing: 'ደግሜ ልሞክር',
    labelButtonProcessItem: 'ልጫን',
    labelMaxFileSizeExceeded: 'ፋይሉ ተልቋል',
    labelMaxFileSize: 'የፋይል መጠን ከ {filesize} መብለጥ አይፈቀድም',
    labelMaxTotalFileSizeExceeded: 'የሚፈቀደውን ጠቅላላ የፋይል መጠን አልፈዋል',
    labelMaxTotalFileSize: 'ጠቅላላ የፋይል መጠን ከ {filesize} መብለጥ አይፈቀድም',
    labelFileTypeNotAllowed: 'የተሳሳተ የፋይል አይነት ነው',
    fileValidateTypeLabelExpectedTypes: 'የፋይል አይነቱ መሆን የሚገባው {allButLastType} እና {lastType} ነው',
    imageValidateSizeLabelFormatError: 'የምስል አይነቱ ለመጫን አይሆንም',
    imageValidateSizeLabelImageSizeTooSmall: 'ምስሉ በጣም አንሷል',
    imageValidateSizeLabelImageSizeTooBig: 'ምስሉ በጣም ተልቋል',
    imageValidateSizeLabelExpectedMinSize: 'ዝቅተኛው የምስል ልኬት {minWidth} × {minHeight} ነው',
    imageValidateSizeLabelExpectedMaxSize: 'ከፍተኛው የምስል ልኬት {maxWidth} × {maxHeight} ነው',
    imageValidateSizeLabelImageResolutionTooLow: 'የምስሉ ጥራት በጣም ዝቅተኛ ነው',
    imageValidateSizeLabelImageResolutionTooHigh: 'የምስሉ ጥራት በጣም ከፍተኛ ነው',
    imageValidateSizeLabelExpectedMinResolution: 'ዝቅተኛው የምስል ጥራት {minResolution} ነው',
    imageValidateSizeLabelExpectedMaxResolution: 'ከፍተኛው የምስል ጥራት {maxResolution} ነው'
};
